@@ -15,6 +15,9 @@
  * You should have received a copy of the GNU General Public License
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  *----------------------------------------------------------------------------
+ * Version 1.7
+ *   - Terminate using exit/return instead of abort (no more "crashes")
+ *
  * Version 1.6
  *   - Zero transparent pixels to guard against invisible color information
  *     (Slight slowdown, but more robustness)
@@ -188,7 +191,7 @@ void write_png(int file_id, uint8_t *image, int w, int h)
 	if ((fh = fopen(filename, "wb")) == NULL)
 	{
 		perror("Cannot open PNG file for writing");
-		abort();
+		exit(1);
 	}
 
 	/* Initialize png struct */
@@ -524,13 +527,13 @@ void mk_timecode (int frame, double fps, char *buf) /* buf must have length 12 (
 	if (h > 99)
 	{
 		fprintf(stderr, "Timecodes above 99:59:59:99 not supported: %Lu:%02u:%02u:%02u\n", h, m, s, frames);
-		abort();
+		exit(1);
 	}
 
 	if (snprintf(buf, 12, "%02d:%02d:%02d:%02d", h, m, s, frames) != 11)
 	{
 		fprintf(stderr, "Timecode lead to invalid format: %s\n", buf);
-		abort();
+		exit(1);
 	}
 }
 
@@ -614,7 +617,7 @@ int main (int argc, char *argv[])
 	if (argc < 7)
 	{
 		print_usage();
-		exit(0);
+		return 0;
 	}
 	avs_filename = argv[1];
 	track_name = argv[2];
@@ -650,7 +653,7 @@ int main (int argc, char *argv[])
 	if (open_file_avis(avs_filename, &avis_hnd, s_info))
 	{
 		print_usage();
-		abort();
+		return 1;
 	}
 	in_img  = calloc(s_info->i_width * s_info->i_height * 4 + 16 * 2, sizeof(char)); /* allocate + 16 for alignment, and + n * 16 for over read/write */
 	old_img = calloc(s_info->i_width * s_info->i_height * 4 + 16 * 2, sizeof(char)); /* see above */
@@ -694,7 +697,7 @@ int main (int argc, char *argv[])
 		if (read_frame_avis(in_img, avis_hnd, i))
 		{
 			fprintf(stderr, "Error reading frame.\n");
-			abort();
+			return 1;
 		}
 		checked_empty = 0;
 
@@ -766,7 +769,7 @@ int main (int argc, char *argv[])
 	if (first_frame == -1)
 	{
 		fprintf(stderr, "No events detected. Refusing to write XML file.\n");
-		abort();
+		return 1;
 	}
 
 	if (detect_sse2())
@@ -780,7 +783,7 @@ int main (int argc, char *argv[])
 	if ((fh = fopen(out_filename, "w")) == 0)
 	{
 		perror("Error opening output file");
-		abort();
+		return 1;
 	}
 
 	/* Write XML header */
